@@ -1,6 +1,8 @@
 #!/usr/bin/python3
 # -*- coding: utf8 -*-
 
+__all__=["sw3"]
+
 from . import libswn as swn
 from .workday import *
 from .database import *
@@ -8,6 +10,8 @@ from .msgc import *
 from .utils import *
 from .sendemail import *
 
+import libsw3 as sw3
+
 import datetime,time,inspect,collections,hashlib,base64,urllib.request,json,subprocess
 import os,re,shutil,smtplib,sys,getpass
 from email import encoders
@@ -194,26 +198,26 @@ def filemd5(filename):#获取文件的md5值
     return m.hexdigest()
 
 def onlyone():  #实例仅运行一次，如果有多于1个则退出运行
+    if len(sys.argv)<2:return
     jg=os.popen("ps ax").read()
-    if len(sys.argv)>1:
-        sj=re.findall("python\s+\S*%s\s+%s" %(sys.argv[0],sys.argv[1]),jg)
-    else:
-        sj=re.findall("python\s+\S*%s" %(sys.argv[0]),jg)
+    sj=re.findall("python\s+\S*%s\s+%s" %(sys.argv[0],sys.argv[1]),jg)
     if len(sj)>1:
-        print("有多于一个的实例，退出")
-        sys.exit(1)
+        异常退出("有多于一个的实例，退出")
 
 class taora(c_oracle):
     def __init__(self,ta="hsta",changeable=False):
         self.ta=ta
         if self.ta in ["hsta","hbetf","lofta","bjhg2"]:
-            oraconn = self.convconn("%s@ta" %(self.ta))
+            self.sora="%s@ta" %(self.ta)
+            print(self.sora)
+            ta自身=c_oracle(self.sora)
+            ta自身.importdbdriver()
+            ta自身.解析连接参数()
+            oraconn = ta自身.连接参数1[0]
             if oraconn == "":
-                swexit(-1,"/etc/oraconn.cfg中未找到%s@ta配置" % (self.ta))
+                swexit(-1,"数据库配置文件中未找到%s@ta配置" % (self.ta))
             self.realuser=oraconn.split("/")[0]#用于自动转换
-            if changeable:
-                self.sora=oraconn
-            else:
+            if not changeable:
                 self.sora = "taro2@ta"
         else:
             swexit(-1,"数据库请求参数有误，只读数据库参数应为：hsta、hbetf、lofta、bjhg、bjhg2之一")
